@@ -9,6 +9,8 @@
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
+#include <termios.h>
+#include <unistd.h>
 
 #include "irman.h"
 
